import {FC, useState} from "react";
import {Image, View} from "@tarojs/components";
import styles from "./home.module.scss";
import Adware from "@/pages/home/components/adware";
import Feature from "@/pages/home/components/feature";
import FeatureRecommended from "@/pages/home/components/feature_recommended";
import CurRecommended from "@/pages/home/components/curRecommended";
import MyButton from "@/components/button/MyButton";
import {Profile} from "@/store";
import Taro from "@tarojs/taro";
import {HomeApi, HomeData} from "@/api";
import logo from '@/static/img/logo.png'


const Home: FC = () => {
  const globalData = Taro.getApp().globalData
  const {token} = Profile.useContainer()
  const [data, setData] = useState<null | HomeData>(null)
  console.log(globalData)

  function unLogin() {
    Taro.removeStorageSync('profile')
    Taro.navigateTo({url: '/pages/login/login'})
  }

  Taro.useLoad(() => {
    HomeApi.home().then(res => {
      setData(res)
    })
  })

  return (
    <View className={styles.content}>
      <View className={styles.header} style={{padding: `${globalData.statusBarHeight}px 0 10px 0`}}>
        <Image src={logo} className={styles.logo} mode='aspectFit'/>
      </View>
      <Adware data={data?.adverts || []} only_flag='routine_home_top_banner' width={710}/>
      <Feature/>
      <FeatureRecommended
        illness={data?.illness.list || []}
        health={data?.health || []}
        brand={data?.brand.list || []}
        skill={data?.skill || []}
      />
      <Adware data={data?.adverts || []} only_flag='routine_home_recommend_banner' width={710}/>
      {data && <CurRecommended/>}
      {
        !token && <View className={styles.tipsLogin} onClick={unLogin}>
          <View>登录后享受更多服务~</View>
          <MyButton fillet size='mini'>立即登录</MyButton>
        </View>
      }
    </View>
  )
}

export default Home
